@@ -345,17 +345,17 @@ libvorbis_version=1.3.7
 libvorbis_patchlevel=1
 ffmpeg3_version=3.2.14
 ffmpeg3_patchlevel=1~deb9u1
-ffmpeg_version=4.4.1
-ffmpeg_patchlevel=1
-libflac_version=1.3.3
+ffmpeg_version=5.0.1
+ffmpeg_patchlevel=3
+libflac_version=1.3.4
 libflac_patchlevel=2
 id3lib_version=3.8.3
 id3lib_patchlevel=16.3
 taglib_version=1.12
-chromaprint_version=1.5.0
+taglib_githash=4e7f844ea6439a5a90546feba359832b2ce2e2e8
+chromaprint_version=1.5.1
 chromaprint_patchlevel=2
-mp4v2_version=2.0.0
-mp4v2_patchlevel=5
+mp4v2_version=2.1.1
 
 # Try to find the configuration from an existing build.
 if test -z "$COMPILER"; then
@@ -390,8 +390,11 @@ if [[ "$QTPREFIX" =~ /([0-9]+)\.([0-9]+)\.([0-9]+)/ ]]; then
   qt_version=$(printf "%d.%d.%d" ${BASH_REMATCH[1]} ${BASH_REMATCH[2]} ${BASH_REMATCH[3]})
   qt_version_major=${BASH_REMATCH[1]}
 else
-  echo "Could not extract Qt version from $QTPREFIX"
-  exit 1
+  echo "Could not extract Qt version from $QTPREFIX, assuming $qt_version"
+  if [[ "$qt_version" =~ ^([0-9]+)\.([0-9]+)\.([0-9]+)$ ]]; then
+    qt_nr=$(printf "%d%02d%02d" ${BASH_REMATCH[1]} ${BASH_REMATCH[2]} ${BASH_REMATCH[3]})
+    qt_version_major=${BASH_REMATCH[1]}
+  fi
 fi
 
 if test "$qt_nr" -ge 51204; then
@@ -581,7 +584,13 @@ fixcmakeinst() {
 test -d source || mkdir source
 cd source
 
-if test -n "${taglib_version##v*}"; then
+if test -n "${taglib_githash}"; then
+  # Download an archive for a git hash
+  if ! test -f taglib-${taglib_githash}.tar.gz; then
+    $DOWNLOAD https://github.com/taglib/taglib/archive/${taglib_githash}.tar.gz
+    mv ${taglib_githash}.tar.gz taglib-${taglib_githash}.tar.gz
+  fi
+elif test -n "${taglib_version##v*}"; then
   test -f taglib-${taglib_version}.tar.gz ||
     $DOWNLOAD http://taglib.github.io/releases/taglib-${taglib_version}.tar.gz
 else
@@ -632,10 +641,8 @@ if test "$compiler" != "cross-android"; then
   test -f chromaprint_${chromaprint_version}-${chromaprint_patchlevel}.debian.tar.xz ||
     $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/c/chromaprint/chromaprint_${chromaprint_version}-${chromaprint_patchlevel}.debian.tar.xz
 
-  test -f mp4v2_${mp4v2_version}~dfsg0.orig.tar.bz2 ||
-    $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/m/mp4v2/mp4v2_${mp4v2_version}~dfsg0.orig.tar.bz2
-  test -f mp4v2_${mp4v2_version}~dfsg0-${mp4v2_patchlevel}.debian.tar.xz ||
-    $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/m/mp4v2/mp4v2_${mp4v2_version}~dfsg0-${mp4v2_patchlevel}.debian.tar.xz
+  test -f mp4v2-${mp4v2_version}.tar.bz2 ||
+    $DOWNLOAD https://github.com/enzo1982/mp4v2/releases/download/v${mp4v2_version}/mp4v2-${mp4v2_version}.tar.bz2
 
 fi # !cross-android
 
@@ -843,18 +850,18 @@ cd ..
 if ! test -d taglib-${taglib_version}; then
   echo "### Extracting taglib"
 
-  tar xzf source/taglib-${taglib_version}.tar.gz
-  cd taglib-${taglib_version}/
-  taglib_nr=${taglib_version:0:3}
-  if test $taglib_nr = "1.1"; then
-    taglib_nr=${taglib_version:0:4}
-    taglib_nr=${taglib_nr/./}
+  if test -n "${taglib_githash}"; then
+    tar xzf source/taglib-${taglib_githash}.tar.gz
+    mv taglib-${taglib_githash} taglib-${taglib_version}
   else
-    taglib_nr=${taglib_nr/./0}
+    tar xzf source/taglib-${taglib_version}.tar.gz
   fi
-  if test "$taglib_nr" = "112"; then
-    if test "$cross_host" = "x86_64-w64-mingw32"; then
-      patch -p1 <$srcdir/packaging/patches/taglib-1.12-win00-large_file.patch
+  cd taglib-${taglib_version}/
+  if test "$cross_host" = "x86_64-w64-mingw32"; then
+    if test -f $srcdir/packaging/patches/taglib-${taglib_githash}-win00-large_file.patch; then
+      patch -p1 <$srcdir/packaging/patches/taglib-${taglib_githash}-win00-large_file.patch
+    else
+      patch -p1 <$srcdir/packaging/patches/taglib-${taglib_version}-win00-large_file.patch
     fi
   fi
   cd ..
@@ -952,19 +959,7 @@ if test "$compiler" != "cross-android"; then
   if ! test -d mp4v2-${mp4v2_version}; then
     echo "### Extracting mp4v2"
 
-    tar xjf source/mp4v2_${mp4v2_version}~dfsg0.orig.tar.bz2
-    cd mp4v2-${mp4v2_version}/
-    tar xJf ../source/mp4v2_${mp4v2_version}~dfsg0-${mp4v2_patchlevel}.debian.tar.xz
-    for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
-    if test $kernel = "MINGW" || test "$compiler" = "cross-mingw"; then
-      patch -p1 <$srcdir/packaging/patches/mp4v2-1.0.0-win00-platform.patch
-      if test -z "${cross_host##x86_64*}"; then
-        sed -i '/^#   define _USE_32BIT_TIME_T/ s#^#//#' libplatform/platform_win32.h
-      fi
-    fi
-    patch -p1 <$srcdir/packaging/patches/mp4v2-1.0.0-0005-Cxx11_compiler.patch
-    patch -p1 <$srcdir/packaging/patches/mp4v2-1.0.0-0004-Pointer_comparison.patch
-    cd ..
+    tar xjf source/mp4v2-${mp4v2_version}.tar.bz2
   fi
 
 fi # !cross-android
@@ -1059,11 +1054,13 @@ if test "$compiler" = "cross-android"; then
 
     if test "${openssl_version:0:3}" = "1.0"; then
       make CALC_VERSIONS="SHLIB_COMPAT=; SHLIB_SOVER=" build_libs
+      _ssl_lib_suffix=.so
     else
-      make ANDROID_NDK_HOME=$ANDROID_NDK_ROOT SHLIB_VERSION_NUMBER= SHLIB_EXT=.so build_libs
+      make ANDROID_NDK_HOME=$ANDROID_NDK_ROOT SHLIB_VERSION_NUMBER= SHLIB_EXT=_1_1.so build_libs
+      _ssl_lib_suffix=_1_1.so
     fi
     mkdir -p inst/usr/local/lib
-    cp --dereference libssl.so libcrypto.so inst/usr/local/lib/
+    cp --dereference libssl${_ssl_lib_suffix} libcrypto${_ssl_lib_suffix} inst/usr/local/lib/
     $_android_prefix-strip -s inst/usr/local/lib/*.so
     cd inst
     tar czf ../../bin/openssl-${openssl_version}.tgz usr
@@ -1418,7 +1415,7 @@ else #  cross-android
 
     # The zlib library path was added for MinGW-builds GCC 4.7.2.
     cd chromaprint-${chromaprint_version}/
-    test -f Makefile || eval cmake -DBUILD_SHARED_LIBS=OFF $CHROMAPRINT_ZLIB_OPTION -DFFMPEG_ROOT=$thisdir/ffmpeg-${ffmpeg_version}/inst/usr/local $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
+    test -f Makefile || eval cmake -DBUILD_SHARED_LIBS=OFF -DBUILD_TESTS=OFF $CHROMAPRINT_ZLIB_OPTION -DFFMPEG_ROOT=$thisdir/ffmpeg-${ffmpeg_version}/inst/usr/local $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
     make VERBOSE=1
     mkdir -p inst
     make install DESTDIR=`pwd`/inst
@@ -1433,10 +1430,11 @@ else #  cross-android
     echo "### Building mp4v2"
 
     cd mp4v2-${mp4v2_version}/
-    autoreconf -i
-    test -f Makefile || CXXFLAGS="$CXXFLAGS -g -O2 -DMP4V2_USE_STATIC_LIB" ./configure --enable-shared=no --enable-static=yes --disable-gch $CONFIGURE_OPTIONS
+    test -f Makefile || eval cmake -DBUILD_SHARED=OFF -DBUILD_UTILS=OFF -DBUILD_SHARED_LIBS=OFF $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
+    make VERBOSE=1
     mkdir -p inst
     make install DESTDIR=`pwd`/inst
+    fixcmakeinst
     cd inst
     tar czf ../../bin/mp4v2-${mp4v2_version}.tgz usr
     cd ../..
