@@ -792,21 +792,46 @@ void DiscogsImporter::HtmlImpl::parseAlbumResults(const QByteArray& albumStr)
           const auto data = dataValue.toObject();
           QJsonObject release;
           QString imgUrl;
+
+          // There are multiple releases in the embedded JSON,
+          // try to find the correct one.
+          const auto rootQuery = data.value(QLatin1String("ROOT_QUERY"))
+              .toObject();
+          for (auto it = rootQuery.constBegin();
+               it != rootQuery.constEnd();
+               ++it) {
+            QString releaseRef;
+            if (it.key().startsWith(QLatin1String("release")) &&
+                !(releaseRef = it.value().toObject()
+                  .value(QLatin1String("__ref")).toString()).isEmpty()) {
+              QJsonObject releaseObject = data.value(releaseRef).toObject();
+              if (releaseObject.contains(QLatin1String("tracks"))) {
+                release = releaseObject;
+                break;
+              }
+            }
+          }
+
           for (auto it = data.constBegin(); it != data.constEnd(); ++it) {
             if (it.key().startsWith(QLatin1String("Release:"))) {
-              const auto releaseValue = it.value();
-              if (releaseValue.isObject()) {
-                release = releaseValue.toObject();
+              QJsonValue releaseValue;
+              if (release.isEmpty() && (releaseValue = it.value()).isObject()) {
+                QJsonObject releaseObject = releaseValue.toObject();
+                if (releaseObject.contains(QLatin1String("tracks"))) {
+                  release = releaseObject;
+                }
               }
             } else if (it.key().startsWith(QLatin1String("Image:"))) {
-              QRegularExpression sourceUrlRe(
-                    QLatin1String("\"sourceUrl\"\\s*:\\s*\"([^\"]+)\""));
-              QString ref = it.value().toObject()
-                  .value(QLatin1String("fullsize")).toObject()
-                  .value(QLatin1String("__ref")).toString();
-              auto match = sourceUrlRe.match(ref);
-              if (match.hasMatch()) {
-                imgUrl = match.captured(1);
+              if (imgUrl.isEmpty()) {
+                QRegularExpression sourceUrlRe(
+                      QLatin1String("\"sourceUrl\"\\s*:\\s*\"([^\"]+)\""));
+                QString ref = it.value().toObject()
+                    .value(QLatin1String("fullsize")).toObject()
+                    .value(QLatin1String("__ref")).toString();
+                auto match = sourceUrlRe.match(ref);
+                if (match.hasMatch()) {
+                  imgUrl = match.captured(1);
+                }
               }
             }
           }
@@ -905,6 +930,7 @@ void DiscogsImporter::HtmlImpl::parseAlbumResults(const QByteArray& albumStr)
           genreStr.replace(nlSpaceRe, QLatin1String(""));
           genreStr = removeHtml(genreStr); // strip HTML tags and entities
           genreStr.remove(QLatin1String("RockStyle:"));
+          genreStr.remove(QLatin1String("PopStyle:"));
           if (genreStr.indexOf(QLatin1Char(',')) >= 0) {
             genreList += genreStr.split(QRegularExpression(QLatin1String(",\\s*")));
           } else {
@@ -1447,6 +1473,20 @@ void DiscogsImporter::sendFindQuery(
   const ServerImporterConfig* cfg,
   const QString& artist, const QString& album)
 {
+  // If an URL is entered in the first search field, its result will be directly
+  // available in the album results list.
+  if (artist.startsWith(QLatin1String("https://www.discogs.com/"))) {
+    const int catBegin = 24;
+    int catEnd = artist.indexOf(QLatin1Char('/'), catBegin);
+    if (catEnd > catBegin) {
+      m_htmlImpl->albumListModel()->clear();
+      m_htmlImpl->albumListModel()->appendItem(
+            artist,
+            artist.mid(catBegin, catEnd - catBegin),
+            artist.mid(catEnd + 1));
+      return;
+    }
+  }
   m_impl = selectImpl(cfg);
   m_impl->sendFindQuery(cfg, artist, album);
 }
